.. openTEPES documentation master file, created by Andres Ramos

Publications
=================
The model has being used in these publications:

- A. Ramos, S. Huclin, J.P. Chaves "Which role will play the pumped-storage hydro and the batteries in the future Spanish system: a case study" IEEE Sustainable Power & Energy Conference iSPEC 2020.
  Chengdu, Sichuan (China). November 2020 (`Presentation <https://pascua.iit.comillas.edu/aramos/papers/Flexibility_iSPEC_China.pdf>`_)
